@@ -3,7 +3,6 @@
 # FOSSLight Binary analysis script
 # Copyright (c) 2020 LG Electronics Inc.
 # SPDX-License-Identifier: Apache-2.0
-import getopt
 import os
 import sys
 from datetime import datetime
@@ -12,15 +11,12 @@ import magic
 import logging
 import yaml
 import stat
-from fosslight_util.help import print_package_version
 from fosslight_util.set_log import init_log
-from fosslight_util.timer_thread import TimerThread
 import fosslight_util.constant as constant
 from fosslight_util.write_txt import write_txt_file
 from fosslight_util.output_format import check_output_format, write_output_file
 from ._binary_dao import get_oss_info_from_db
 from ._binary import BinaryItem
-from ._help import print_help_msg
 from ._jar_analysis import analyze_jar_file, merge_binary_list
 
 _PKG_NAME = "fosslight_binary"
@@ -41,6 +37,7 @@ _error_logs = []
 _root_path = ""
 _start_time = ""
 windows = False
+BYTES = 2048
 
 JAR_VUL_HEADER = {'BIN_FL_Binary': ['ID', 'Source Name or Path', 'OSS Name',
                                     'OSS Version', 'License', 'Download Location',
@@ -53,7 +50,7 @@ def init(path_to_find_bin, output_file_name, format):
 
     _json_ext = ".json"
     _yaml_ext = ".yaml"
-    _start_time = datetime.now().strftime('%Y%m%d_%H%M%S')
+    _start_time = datetime.now().strftime('%y%m%d_%H%M')
     _result_log = {
         "Tool Info": _PKG_NAME
     }
@@ -74,11 +71,11 @@ def init(path_to_find_bin, output_file_name, format):
             bin_txt_file = f"{output_file}.txt"
         else:
             if output_extension == _json_ext:
-                result_report = f"Opossum_input_{_start_time}"
+                result_report = f"fosslight_opossum_{_start_time}"
             elif output_extension == _yaml_ext:
                 result_report = f"fosslight-sbom-info_{_start_time}"
             else:
-                result_report = f"FOSSLight-Report_{_start_time}"
+                result_report = f"fosslight_report_{_start_time}"
             bin_txt_file = f"binary_{_start_time}.txt"
 
         result_report = os.path.join(output_path, result_report)
@@ -87,7 +84,7 @@ def init(path_to_find_bin, output_file_name, format):
         logger.error(f"Format error - {msg}")
         sys.exit(1)
 
-    log_file = os.path.join(output_path, f"fosslight_bin_log_{_start_time}.txt")
+    log_file = os.path.join(output_path, f"fosslight_log_{_start_time}.txt")
     logger, _result_log = init_log(log_file, True, logging.INFO, logging.DEBUG, _PKG_NAME, path_to_find_bin)
 
     if not success:
@@ -209,41 +206,43 @@ def find_binaries(path_to_find_bin, output_dir, format, dburl=""):
 
 
 def return_bin_only(file_list, need_checksum_tlsh=True):
-    BYTES = 2048
     for file_item in file_list:
-        is_bin_confirmed = False
-        file_with_path = file_item.bin_name
-        file = file_item.binary_name_without_path
-        extension = os.path.splitext(file)[1][1:]
-        if not os.path.islink(file_with_path) and extension.lower() not in _REMOVE_FILE_EXTENSION:
-            if stat.S_ISFIFO(os.stat(file_with_path).st_mode):
-                continue
-            file_command_result = ""
-            file_command_failed = False
-            try:
-                file_command_result = magic.from_file(file_with_path)
-            except Exception:
-                file_command_failed = True
-            if file_command_failed:
-                try:
-                    file_command_result = magic.from_buffer(open(file_with_path).read(BYTES))
-                except Exception as ex:
-                    logger.debug(f"Failed to check file type:{file_with_path}, {ex}")
+        if check_binary(file_item.bin_name):
+            if need_checksum_tlsh:
+                error, error_msg = file_item.set_checksum_tlsh()
+                if error:
+                    error_occured(error_msg=error_msg, exit=False)
+            yield file_item
 
-            if file_command_result:
-                file_command_result = file_command_result.lower()
-                if any(file_command_result.startswith(x) for x in _REMOVE_FILE_COMMAND_RESULT):
-                    continue
-                if any(file_command_result.startswith(x) for x in INCLUDE_FILE_COMMAND_RESULT):
-                    is_bin_confirmed = True
-            if is_binary(file_with_path):
+
+def check_binary(file_with_path):
+    is_bin_confirmed = False
+    file = os.path.basename(file_with_path)
+    extension = os.path.splitext(file)[1][1:]
+    if not os.path.islink(file_with_path) and extension.lower() not in _REMOVE_FILE_EXTENSION:
+        if stat.S_ISFIFO(os.stat(file_with_path).st_mode):
+            return False
+        file_command_result = ""
+        file_command_failed = False
+        try:
+            file_command_result = magic.from_file(file_with_path)
+        except Exception:
+            file_command_failed = True
+        if file_command_failed:
+            try:
+                file_command_result = magic.from_buffer(open(file_with_path).read(BYTES))
+            except Exception as ex:
+                logger.debug(f"Failed to check file type:{file_with_path}, {ex}")
+
+        if file_command_result:
+            file_command_result = file_command_result.lower()
+            if any(file_command_result.startswith(x) for x in _REMOVE_FILE_COMMAND_RESULT):
+                return False
+            if any(file_command_result.startswith(x) for x in INCLUDE_FILE_COMMAND_RESULT):
                 is_bin_confirmed = True
-            if is_bin_confirmed:
-                if need_checksum_tlsh:
-                    error, error_msg = file_item.set_checksum_tlsh()
-                    if error:
-                        error_occured(error_msg=error_msg, exit=False)
-                yield file_item
+        if is_binary(file_with_path):
+            is_bin_confirmed = True
+    return is_bin_confirmed
 
 
 def error_occured(error_msg, exit=False, result_log={}):
@@ -274,42 +273,3 @@ def print_result_log(success=True, result_log={}, file_cnt="", bin_file_cnt="",
         logger.info(_str_final_result_log)
     except Exception as ex:
         logger.warning(f"Error to print final log: {ex}")
-
-
-def main():
-    global windows
-    argv = sys.argv[1:]
-    output_dir = ""
-    path_to_find_bin = os.getcwd()
-    format = ""
-    db_url = ""
-
-    try:
-        opts, args = getopt.getopt(argv, 'hvp:o:f:d:')
-        for opt, arg in opts:
-            if opt == "-h":
-                print_help_msg()
-            elif opt == "-v":
-                print_package_version(_PKG_NAME, "FOSSLight Binary Scanner Version:")
-            elif opt == "-p":
-                path_to_find_bin = arg
-                if not path_to_find_bin:
-                    path_to_find_bin = os.getcwd()
-            elif opt == "-o":
-                output_dir = arg
-            elif opt == "-f":
-                format = arg
-            elif opt == "-d":
-                db_url = arg
-    except Exception:
-        print_help_msg()
-
-    timer = TimerThread()
-    timer.setDaemon(True)
-    timer.start()
-
-    find_binaries(path_to_find_bin, output_dir, format, db_url)
-
-
-if __name__ == '__main__':
-    main()
